@@ -99,6 +99,6 @@
 #' }
 #' 
 #' @name pixiedust
-#' @docType package
+#' @keywords internal
 
-NULL
\ No newline at end of file
+"_PACKAGE"
\ No newline at end of file
